@@ -30,7 +30,6 @@
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_FCNTL_H 1
-#define HAVE_FCNTL_DIRECT 1
 #define HAVE_FENV_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
@@ -128,7 +127,6 @@
 /* Functions we may want to use. */
 #define HAVE_ACCEPT4 1
 #define HAVE_ACCESS 1
-#define HAVE_ALARM 1
 #define HAVE_ALLOCA 1
 /* #undef HAVE_BFILL */
 #define HAVE_INDEX 1
@@ -256,6 +254,7 @@
 /* #undef HAVE_SOCKADDR_IN6_SIN6_LEN */
 #define STRUCT_TIMESPEC_HAS_TV_SEC 1
 #define STRUCT_TIMESPEC_HAS_TV_NSEC 1
+#define STRUCT_TM_HAS_TM_GMTOFF 1
 
 /* this means that valgrind headers and macros are available */
 /* #undef HAVE_VALGRIND_MEMCHECK_H */
@@ -378,14 +377,13 @@
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
 #define HAVE_ERR_remove_thread_state 1
-#define HAVE_X509_check_host 1
+/* #undef HAVE_X509_check_host */
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
 #define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
 /* #undef NO_FCNTL_NONBLOCK */
-#define NO_ALARM 1
 
 /* #undef _LARGE_FILES */
 #define _LARGEFILE_SOURCE 1
@@ -500,6 +498,8 @@
 #define HAVE_COMPRESS 1
 #define HAVE_EncryptAes128Ctr 1
 #define HAVE_EncryptAes128Gcm 1
+#define HAVE_des 1
+#define HAVE_hkdf 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -531,17 +531,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 11
-#define MYSQL_VERSION_MINOR 2
-#define MYSQL_VERSION_PATCH 3
+#define MYSQL_VERSION_MINOR 4
+#define MYSQL_VERSION_PATCH 2
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 11.2.3"
+#define PACKAGE_STRING "MySQL Server 11.4.2"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "11.2.3"
-#define VERSION "11.2.3"
+#define PACKAGE_VERSION "11.4.2"
+#define VERSION "11.4.2"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
